@@ -146,6 +146,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -209,6 +211,9 @@ class HttpOrigin(
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(HttpOrigin.__init__)
+            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
         props = HttpOriginProps(
             http_port=http_port,
             https_port=https_port,
@@ -305,6 +310,19 @@ class HttpOriginProps(aws_cdk.aws_cloudfront.OriginProps):
                 read_timeout=cdk.Duration.minutes(30)
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(HttpOriginProps.__init__)
+            check_type(argname="argument connection_attempts", value=connection_attempts, expected_type=type_hints["connection_attempts"])
+            check_type(argname="argument connection_timeout", value=connection_timeout, expected_type=type_hints["connection_timeout"])
+            check_type(argname="argument custom_headers", value=custom_headers, expected_type=type_hints["custom_headers"])
+            check_type(argname="argument origin_shield_region", value=origin_shield_region, expected_type=type_hints["origin_shield_region"])
+            check_type(argname="argument origin_path", value=origin_path, expected_type=type_hints["origin_path"])
+            check_type(argname="argument http_port", value=http_port, expected_type=type_hints["http_port"])
+            check_type(argname="argument https_port", value=https_port, expected_type=type_hints["https_port"])
+            check_type(argname="argument keepalive_timeout", value=keepalive_timeout, expected_type=type_hints["keepalive_timeout"])
+            check_type(argname="argument origin_ssl_protocols", value=origin_ssl_protocols, expected_type=type_hints["origin_ssl_protocols"])
+            check_type(argname="argument protocol_policy", value=protocol_policy, expected_type=type_hints["protocol_policy"])
+            check_type(argname="argument read_timeout", value=read_timeout, expected_type=type_hints["read_timeout"])
         self._values: typing.Dict[str, typing.Any] = {}
         if connection_attempts is not None:
             self._values["connection_attempts"] = connection_attempts
@@ -521,6 +539,9 @@ class LoadBalancerV2Origin(
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LoadBalancerV2Origin.__init__)
+            check_type(argname="argument load_balancer", value=load_balancer, expected_type=type_hints["load_balancer"])
         props = LoadBalancerV2OriginProps(
             http_port=http_port,
             https_port=https_port,
@@ -601,6 +622,19 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
                 protocol_policy=cloudfront.OriginProtocolPolicy.MATCH_VIEWER
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LoadBalancerV2OriginProps.__init__)
+            check_type(argname="argument connection_attempts", value=connection_attempts, expected_type=type_hints["connection_attempts"])
+            check_type(argname="argument connection_timeout", value=connection_timeout, expected_type=type_hints["connection_timeout"])
+            check_type(argname="argument custom_headers", value=custom_headers, expected_type=type_hints["custom_headers"])
+            check_type(argname="argument origin_shield_region", value=origin_shield_region, expected_type=type_hints["origin_shield_region"])
+            check_type(argname="argument origin_path", value=origin_path, expected_type=type_hints["origin_path"])
+            check_type(argname="argument http_port", value=http_port, expected_type=type_hints["http_port"])
+            check_type(argname="argument https_port", value=https_port, expected_type=type_hints["https_port"])
+            check_type(argname="argument keepalive_timeout", value=keepalive_timeout, expected_type=type_hints["keepalive_timeout"])
+            check_type(argname="argument origin_ssl_protocols", value=origin_ssl_protocols, expected_type=type_hints["origin_ssl_protocols"])
+            check_type(argname="argument protocol_policy", value=protocol_policy, expected_type=type_hints["protocol_policy"])
+            check_type(argname="argument read_timeout", value=read_timeout, expected_type=type_hints["read_timeout"])
         self._values: typing.Dict[str, typing.Any] = {}
         if connection_attempts is not None:
             self._values["connection_attempts"] = connection_attempts
@@ -819,6 +853,9 @@ class OriginGroup(
         :param scope: -
         :param origin_id: The identifier of this Origin, as assigned by the Distribution this Origin has been used added to.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(OriginGroup.bind)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         options = aws_cdk.aws_cloudfront.OriginBindOptions(origin_id=origin_id)
 
         return typing.cast(aws_cdk.aws_cloudfront.OriginBindConfig, jsii.invoke(self, "bind", [scope, options]))
@@ -863,6 +900,11 @@ class OriginGroupProps:
                 )
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(OriginGroupProps.__init__)
+            check_type(argname="argument fallback_origin", value=fallback_origin, expected_type=type_hints["fallback_origin"])
+            check_type(argname="argument primary_origin", value=primary_origin, expected_type=type_hints["primary_origin"])
+            check_type(argname="argument fallback_status_codes", value=fallback_status_codes, expected_type=type_hints["fallback_status_codes"])
         self._values: typing.Dict[str, typing.Any] = {
             "fallback_origin": fallback_origin,
             "primary_origin": primary_origin,
@@ -943,6 +985,9 @@ class RestApiOrigin(
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RestApiOrigin.__init__)
+            check_type(argname="argument rest_api", value=rest_api, expected_type=type_hints["rest_api"])
         props = RestApiOriginProps(
             keepalive_timeout=keepalive_timeout,
             read_timeout=read_timeout,
@@ -1013,6 +1058,14 @@ class RestApiOriginProps(aws_cdk.aws_cloudfront.OriginOptions):
                 read_timeout=cdk.Duration.minutes(30)
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RestApiOriginProps.__init__)
+            check_type(argname="argument connection_attempts", value=connection_attempts, expected_type=type_hints["connection_attempts"])
+            check_type(argname="argument connection_timeout", value=connection_timeout, expected_type=type_hints["connection_timeout"])
+            check_type(argname="argument custom_headers", value=custom_headers, expected_type=type_hints["custom_headers"])
+            check_type(argname="argument origin_shield_region", value=origin_shield_region, expected_type=type_hints["origin_shield_region"])
+            check_type(argname="argument keepalive_timeout", value=keepalive_timeout, expected_type=type_hints["keepalive_timeout"])
+            check_type(argname="argument read_timeout", value=read_timeout, expected_type=type_hints["read_timeout"])
         self._values: typing.Dict[str, typing.Any] = {}
         if connection_attempts is not None:
             self._values["connection_attempts"] = connection_attempts
@@ -1164,6 +1217,9 @@ class S3Origin(
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(S3Origin.__init__)
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
         props = S3OriginProps(
             origin_access_identity=origin_access_identity,
             origin_path=origin_path,
@@ -1187,6 +1243,9 @@ class S3Origin(
         :param scope: -
         :param origin_id: The identifier of this Origin, as assigned by the Distribution this Origin has been used added to.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(S3Origin.bind)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         options = aws_cdk.aws_cloudfront.OriginBindOptions(origin_id=origin_id)
 
         return typing.cast(aws_cdk.aws_cloudfront.OriginBindConfig, jsii.invoke(self, "bind", [scope, options]))
@@ -1237,6 +1296,14 @@ class S3OriginProps(aws_cdk.aws_cloudfront.OriginProps):
                 ))
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(S3OriginProps.__init__)
+            check_type(argname="argument connection_attempts", value=connection_attempts, expected_type=type_hints["connection_attempts"])
+            check_type(argname="argument connection_timeout", value=connection_timeout, expected_type=type_hints["connection_timeout"])
+            check_type(argname="argument custom_headers", value=custom_headers, expected_type=type_hints["custom_headers"])
+            check_type(argname="argument origin_shield_region", value=origin_shield_region, expected_type=type_hints["origin_shield_region"])
+            check_type(argname="argument origin_path", value=origin_path, expected_type=type_hints["origin_path"])
+            check_type(argname="argument origin_access_identity", value=origin_access_identity, expected_type=type_hints["origin_access_identity"])
         self._values: typing.Dict[str, typing.Any] = {}
         if connection_attempts is not None:
             self._values["connection_attempts"] = connection_attempts
